@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -31,9 +31,21 @@
 #include "SysCPUx86.h"
 
 #else           // #ifdef XMAIL_X86
+#ifdef XMAIL_SPARC
+
+#include "SysCPUSPARC.h"
+
+#else           // #ifdef XMAIL_SPARC
+#ifdef XMAIL_PPC
+
+#include "SysCPUPPC.h"
+
+#else           // #ifdef XMAIL_PPC
 
 #error CPU type not defined
 
+#endif          // #ifdef XMAIL_PPC
+#endif          // #ifdef XMAIL_SPARC
 #endif          // #ifdef XMAIL_X86
 
 
