@@ -278,6 +278,8 @@ static ErrorStrings Errors[] =
     {ERR_DUPLICATE_HANDLE, "Error in function {DuplicateHandle}"},
     {ERR_EMPTY_LOG, "Log file is empty"},
     {ERR_BAD_RELATIVE_PATH, "Error in relative path syntax"},
+    {ERR_DNS_NXDOMAIN, "DNS name not exist"},
+    {ERR_BAD_RFCNAME, "Name does not respect RFC822"},
 
 };
 
