@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -27,13 +27,16 @@
 #include "ShBlocks.h"
 #include "SList.h"
 #include "BuffSock.h"
+#include "StrUtils.h"
 #include "ResLocks.h"
 #include "MiscUtils.h"
 #include "SvrUtils.h"
 #include "UsrUtils.h"
 #include "ExtAliases.h"
 #include "UsrMailList.h"
+#include "MessQueue.h"
 #include "SMTPUtils.h"
+#include "MailConfig.h"
 #include "AppDefines.h"
 #include "MailSvr.h"
 #include "FINGSvr.h"
@@ -46,9 +49,10 @@
 
 
 #define FINGSRV_ACCEPT_TIMEOUT  4
-#define FING_LISTEN_SIZE        8
+#define FING_LISTEN_SIZE        64
 #define FING_WAIT_SLEEP         2
 #define MAX_CLIENTS_WAIT        300
+#define FING_IPMAP_FILE         "finger.ipmap.tab"
 #define FING_LOG_FILE           "finger"
 #define FING_SERVER_NAME        "[" APP_NAME_VERSION_OS_STR " FINGER Server]"
 
@@ -60,6 +64,7 @@
 
 
 
+static int      FINGCheckPeerIP(SYS_SOCKET SockFD);
 static FINGConfig *FINGGetConfigCopy(SHB_HANDLE hShbFING);
 static int      FINGLogEnabled(SHB_HANDLE hShbFING, FINGConfig * pFINGCfg = NULL);
 static unsigned int FINGClientThread(void *pThreadData);
@@ -79,6 +84,35 @@ static int      FINGDumpMailingList(UserInfo * pUI, BSOCK_HANDLE hBSock, FINGCon
 
 
 
+
+
+
+
+static int      FINGCheckPeerIP(SYS_SOCKET SockFD)
+{
+
+    char            szIPMapFile[SYS_MAX_PATH] = "";
+
+    CfgGetRootPath(szIPMapFile, sizeof(szIPMapFile));
+    StrNCat(szIPMapFile, FING_IPMAP_FILE, sizeof(szIPMapFile));
+
+    if (SysExistFile(szIPMapFile))
+    {
+        SYS_INET_ADDR   PeerInfo;
+
+        if (SysGetPeerInfo(SockFD, PeerInfo) < 0)
+            return (ErrGetErrorCode());
+
+        if (MscCheckAllowedIP(szIPMapFile, PeerInfo, true) < 0)
+            return (ErrGetErrorCode());
+    }
+
+    return (0);
+
+}
+
+
+
 static FINGConfig *FINGGetConfigCopy(SHB_HANDLE hShbFING)
 {
 
@@ -130,11 +164,9 @@ static unsigned int FINGClientThread(void *pThreadData)
     SYS_SOCKET      SockFD = (SYS_SOCKET) (unsigned int) pThreadData;
 
 ///////////////////////////////////////////////////////////////////////////////
-//  Create handle to hook shared memory
+//  Check peer IP address serivce access permissions
 ///////////////////////////////////////////////////////////////////////////////
-    SHB_HANDLE      hShbFING = ShbConnectBlock(SHB_FINGSvr);
-
-    if (hShbFING == SHB_INVALID_HANDLE)
+    if (FINGCheckPeerIP(SockFD) < 0)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
@@ -152,7 +184,6 @@ static unsigned int FINGClientThread(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         SysCloseSocket(SockFD);
-        ShbCloseBlock(hShbFING);
         return (ErrorPop());
     }
 
@@ -170,7 +201,6 @@ static unsigned int FINGClientThread(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         SysCloseSocket(SockFD);
-        ShbCloseBlock(hShbFING);
         return (ErrorPop());
     }
 
@@ -195,7 +225,6 @@ static unsigned int FINGClientThread(void *pThreadData)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        ShbCloseBlock(hShbFING);
         return (ErrorPop());
     }
 
@@ -203,8 +232,6 @@ static unsigned int FINGClientThread(void *pThreadData)
 
     ShbUnlock(hShbFING);
 
-    ShbCloseBlock(hShbFING);
-
     return (0);
 
 }
@@ -215,22 +242,12 @@ static unsigned int FINGClientThread(void *pThreadData)
 unsigned int    FINGThreadProc(void *pThreadData)
 {
 
-    SHB_HANDLE      hShbFING = ShbConnectBlock(SHB_FINGSvr);
-
-    if (hShbFING == SHB_INVALID_HANDLE)
-    {
-        ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        return (ErrorPop());
-    }
-
     FINGConfig     *pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
 
     if (pFINGCfg == NULL)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        ShbCloseBlock(hShbFING);
         return (ErrorPop());
     }
 
@@ -244,14 +261,11 @@ unsigned int    FINGThreadProc(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         ShbUnlock(hShbFING);
-        ShbCloseBlock(hShbFING);
         return (ErrorPop());
     }
 
     ShbUnlock(hShbFING);
 
-    SysIgnoreThreadsExit();
-
 
     SysLogMessage(LOG_LEV_MESSAGE, "%s started\n", FING_SERVER_NAME);
 
@@ -285,7 +299,7 @@ unsigned int    FINGThreadProc(void *pThreadData)
             if (hClientThread != SYS_INVALID_THREAD)
                 SysCloseThread(hClientThread, 0);
             else
-                SysCloseSocket(ConnSockFD[ss], 1);
+                SysCloseSocket(ConnSockFD[ss]);
 
         }
     }
@@ -313,8 +327,6 @@ unsigned int    FINGThreadProc(void *pThreadData)
         SysSleep(FING_WAIT_SLEEP);
     }
 
-    ShbCloseBlock(hShbFING);
-
     SysLogMessage(LOG_LEV_MESSAGE, "%s stopped\n", FING_SERVER_NAME);
 
     return (0);
@@ -333,18 +345,20 @@ static int      FINGLogSession(char const * pszSockHost, char const * pszSockDom
     MscGetTimeNbrString(szTime, sizeof(szTime) - 1);
 
 
-    RLCK_HANDLE     hResLock = RLckLockEX(SVR_LOGS_DIR "/" FING_LOG_FILE);
+    RLCK_HANDLE     hResLock = RLckLockEX(SVR_LOGS_DIR SYS_SLASH_STR FING_LOG_FILE);
 
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
 
 
+    char            szIP[128] = "???.???.???.???";
+
     MscFileLog(FING_LOG_FILE, "\"%s\""
             "\t\"%s\""
             "\t\"%s\""
             "\t\"%s\""
             "\t\"%s\""
-            "\n", pszSockHost, pszSockDomain, SysInetNToA(PeerInfo),
+            "\n", pszSockHost, pszSockDomain, SysInetNToA(PeerInfo, szIP),
             szTime, pszQuery);
 
 
@@ -398,14 +412,16 @@ static int      FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock)
 
     MscSplitFQDN(szSvrFQDN, szSockHost, szSockDomain);
 
+    char            szIP[128] = "???.???.???.???";
 
     SysLogMessage(LOG_LEV_MESSAGE, "FINGER client connection from [%s]\n",
-            SysInetNToA(PeerInfo));
+            SysInetNToA(PeerInfo, szIP));
 
 
-    char            szQuery[2048] = "";
+    char            szQuery[1024] = "";
 
-    if (BSckGetString(hBSock, szQuery, sizeof(szQuery) - 1, pFINGCfg->iTimeout) != NULL)
+    if ((BSckGetString(hBSock, szQuery, sizeof(szQuery) - 1, pFINGCfg->iTimeout) != NULL) &&
+            (MscCmdStringCheck(szQuery) == 0))
     {
 ///////////////////////////////////////////////////////////////////////////////
 //  Log FINGER question
@@ -414,7 +430,7 @@ static int      FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock)
             FINGLogSession(szSockHost, szSockDomain, PeerInfo, szQuery);
 
         SysLogMessage(LOG_LEV_MESSAGE, "FINGER query [%s] : \"%s\"\n",
-                SysInetNToA(PeerInfo), szQuery);
+                SysInetNToA(PeerInfo, szIP), szQuery);
 
 
         SVRCFG_HANDLE   hSvrConfig = SvrGetConfigHandle();
@@ -431,7 +447,7 @@ static int      FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock)
 
 
     SysLogMessage(LOG_LEV_MESSAGE, "FINGER client exit [%s]\n",
-            SysInetNToA(PeerInfo));
+            SysInetNToA(PeerInfo, szIP));
 
     return (0);
 
@@ -510,7 +526,7 @@ static int      FINGProcessQuery(char const * pszQuery, BSOCK_HANDLE hBSock,
 ///////////////////////////////////////////////////////////////////////////////
 //  Setup domain name in case of username only query
 ///////////////////////////////////////////////////////////////////////////////
-    if (strlen(szDomain) == 0)
+    if (IsEmptyString(szDomain))
     {
         if (SvrConfigVar("POP3Domain", szDomain, sizeof(szDomain), hSvrConfig) < 0)
         {
@@ -526,7 +542,7 @@ static int      FINGProcessQuery(char const * pszQuery, BSOCK_HANDLE hBSock,
                 }
             }
             else
-                strcpy(szDomain, pszSockDomain);
+                StrSNCpy(szDomain, pszSockDomain);
         }
     }
 
@@ -555,8 +571,8 @@ static int      FINGDumpUser(char const * pszUser, char const * pszDomain,
 ///////////////////////////////////////////////////////////////////////////////
 //  Lookup user
 ///////////////////////////////////////////////////////////////////////////////
-    char            szRealUser[MAX_ADDR_NAME] = "";
-    UserInfo       *pUI = UsrGetUserByNameOrAlias(pszDomain, pszUser, szRealUser);
+    char            szRealAddr[MAX_ADDR_NAME] = "";
+    UserInfo       *pUI = UsrGetUserByNameOrAlias(pszDomain, pszUser, szRealAddr);
 
     if (pUI != NULL)
     {
@@ -570,10 +586,10 @@ static int      FINGDumpUser(char const * pszUser, char const * pszDomain,
             char            szRespBuffer[2048] = "";
 
             sprintf(szRespBuffer,
-                    "EMail       : %s@%s\r\n"
+                    "EMail       : %s\r\n"
                     "  Real Name : %s\r\n"
                     "  Home Page : %s",
-                    szRealUser, pszDomain,
+                    szRealAddr,
                     (pszRealName != NULL) ? pszRealName : "??",
                     (pszHomePage != NULL) ? pszHomePage : "??");
 
