@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "SList.h"
 #include "BuffSock.h"
 #include "MailConfig.h"
+#include "MessQueue.h"
 #include "MailSvr.h"
 #include "MiscUtils.h"
 #include "SvrUtils.h"
@@ -38,6 +39,8 @@
 #include "UsrUtils.h"
 #include "UsrAuth.h"
 #include "TabIndex.h"
+#include "AliasDomain.h"
+#include "SMAILUtils.h"
 #include "MailDomains.h"
 
 
@@ -82,7 +85,7 @@ struct DomainsScanData
 
 
 static int      MDomRebuildDomainsIndexes(char const * pszDomainsFilePath);
-static char    *MDomGetDomainsFilePath(char *pszDomainsFilePath);
+static char    *MDomGetDomainsFilePath(char *pszDomainsFilePath, int iMaxPath);
 
 
 
@@ -115,7 +118,7 @@ int             MDomCheckDomainsIndexes(void)
 
     char            szDomainsFilePath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainsFilePath(szDomainsFilePath);
+    MDomGetDomainsFilePath(szDomainsFilePath, sizeof(szDomainsFilePath));
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Align RmtDomain-RmtName index
@@ -149,15 +152,23 @@ static int      MDomRebuildDomainsIndexes(char const * pszDomainsFilePath)
 
 
 
-char           *MDomGetDomainPath(char const * pszDomain, char *pszDomainPath,
+char           *MDomGetDomainPath(char const * pszDomain, char *pszDomainPath, int iMaxPath,
                         int iFinalSlash)
 {
+///////////////////////////////////////////////////////////////////////////////
+//  Make the domain lower-case
+///////////////////////////////////////////////////////////////////////////////
+    char            szLoDomain[SYS_MAX_PATH] = "";
 
-    CfgGetRootPath(pszDomainPath);
+    StrSNCpy(szLoDomain, pszDomain);
+    StrLower(szLoDomain);
 
-    strcat(pszDomainPath, MAIL_DOMAINS_DIR);
+
+    CfgGetRootPath(pszDomainPath, iMaxPath);
+
+    StrNCat(pszDomainPath, MAIL_DOMAINS_DIR, iMaxPath);
     AppendSlash(pszDomainPath);
-    strcat(pszDomainPath, pszDomain);
+    StrNCat(pszDomainPath, szLoDomain, iMaxPath);
 
     if (iFinalSlash)
         AppendSlash(pszDomainPath);
@@ -169,12 +180,12 @@ char           *MDomGetDomainPath(char const * pszDomain, char *pszDomainPath,
 
 
 
-static char    *MDomGetDomainsFilePath(char *pszDomainsFilePath)
+static char    *MDomGetDomainsFilePath(char *pszDomainsFilePath, int iMaxPath)
 {
 
-    CfgGetRootPath(pszDomainsFilePath);
+    CfgGetRootPath(pszDomainsFilePath, iMaxPath);
 
-    strcat(pszDomainsFilePath, MAIL_DOMAINS_FILE);
+    StrNCat(pszDomainsFilePath, MAIL_DOMAINS_FILE, iMaxPath);
 
     return (pszDomainsFilePath);
 
@@ -183,16 +194,17 @@ static char    *MDomGetDomainsFilePath(char *pszDomainsFilePath)
 
 
 
-int             MDomIsHandledDomain(char const * pszDomain)
+int             MDomLookupDomain(char const * pszDomain)
 {
 
     char            szDomainsFilePath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainsFilePath(szDomainsFilePath);
+    MDomGetDomainsFilePath(szDomainsFilePath, sizeof(szDomainsFilePath));
 
 
     char            szResLock[SYS_MAX_PATH] = "";
-    RLCK_HANDLE     hResLock = RLckLockSH(CfgGetBasedPath(szDomainsFilePath, szResLock));
+    RLCK_HANDLE     hResLock = RLckLockSH(CfgGetBasedPath(szDomainsFilePath, szResLock,
+                            sizeof(szResLock)));
 
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
@@ -231,11 +243,12 @@ int             MDomAddDomain(char const * pszDomain)
 
     char            szDomainsFilePath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainsFilePath(szDomainsFilePath);
+    MDomGetDomainsFilePath(szDomainsFilePath, sizeof(szDomainsFilePath));
 
 
     char            szResLock[SYS_MAX_PATH] = "";
-    RLCK_HANDLE     hResLock = RLckLockEX(CfgGetBasedPath(szDomainsFilePath, szResLock));
+    RLCK_HANDLE     hResLock = RLckLockEX(CfgGetBasedPath(szDomainsFilePath, szResLock,
+                            sizeof(szResLock)));
 
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
@@ -291,9 +304,12 @@ int             MDomAddDomain(char const * pszDomain)
         return (ErrorPop());
     }
 
+///////////////////////////////////////////////////////////////////////////////
+//  Create domain directory
+///////////////////////////////////////////////////////////////////////////////
     char            szDomainPath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainPath(pszDomain, szDomainPath, 0);
+    MDomGetDomainPath(pszDomain, szDomainPath, sizeof(szDomainPath), 0);
 
     if (SysMakeDir(szDomainPath) < 0)
     {
@@ -302,6 +318,16 @@ int             MDomAddDomain(char const * pszDomain)
         return (ErrorPop());
     }
 
+///////////////////////////////////////////////////////////////////////////////
+//  Create cmd alias directory
+///////////////////////////////////////////////////////////////////////////////
+    if (USmlCreateCmdAliasDomainDir(pszDomain) < 0)
+    {
+        ErrorPush();
+        RLckUnlockEX(hResLock);
+        return (ErrorPop());
+    }
+
 
     RLckUnlockEX(hResLock);
 
@@ -317,7 +343,7 @@ int             MDomRemoveDomain(char const * pszDomain)
 
     char            szDomainsFilePath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainsFilePath(szDomainsFilePath);
+    MDomGetDomainsFilePath(szDomainsFilePath, sizeof(szDomainsFilePath));
 
 
     char            szTmpFile[SYS_MAX_PATH] = "";
@@ -326,7 +352,8 @@ int             MDomRemoveDomain(char const * pszDomain)
 
 
     char            szResLock[SYS_MAX_PATH] = "";
-    RLCK_HANDLE     hResLock = RLckLockEX(CfgGetBasedPath(szDomainsFilePath, szResLock));
+    RLCK_HANDLE     hResLock = RLckLockEX(CfgGetBasedPath(szDomainsFilePath, szResLock,
+                            sizeof(szResLock)));
 
     if (hResLock == INVALID_RLCK_HANDLE)
     {
@@ -443,6 +470,9 @@ int             MDomRemoveDomain(char const * pszDomain)
     if (GwLkRemoveDomainLinks(pszDomain) < 0)
         return (ErrGetErrorCode());
 
+    if (ADomRemoveLinkedDomains(pszDomain) < 0)
+        return (ErrGetErrorCode());
+
 ///////////////////////////////////////////////////////////////////////////////
 //  Try ( if defined ) to drop external auth domain
 ///////////////////////////////////////////////////////////////////////////////
@@ -454,7 +484,7 @@ int             MDomRemoveDomain(char const * pszDomain)
 ///////////////////////////////////////////////////////////////////////////////
     char            szDomainPath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainPath(pszDomain, szDomainPath, 0);
+    MDomGetDomainPath(pszDomain, szDomainPath, sizeof(szDomainPath), 0);
 
     if (MscClearDirectory(szDomainPath) < 0)
         return (ErrGetErrorCode());
@@ -462,6 +492,13 @@ int             MDomRemoveDomain(char const * pszDomain)
     if (SysRemoveDir(szDomainPath) < 0)
         return (ErrGetErrorCode());
 
+///////////////////////////////////////////////////////////////////////////////
+//  Remove the cmd alias directory
+///////////////////////////////////////////////////////////////////////////////
+    if (USmlDeleteCmdAliasDomainDir(pszDomain) < 0)
+        return (ErrGetErrorCode());
+
+
     return (0);
 
 }
@@ -474,11 +511,12 @@ int             MDomGetDomainsFileSnapShot(const char *pszFileName)
 
     char            szDomainsFilePath[SYS_MAX_PATH] = "";
 
-    MDomGetDomainsFilePath(szDomainsFilePath);
+    MDomGetDomainsFilePath(szDomainsFilePath, sizeof(szDomainsFilePath));
 
 
     char            szResLock[SYS_MAX_PATH] = "";
-    RLCK_HANDLE     hResLock = RLckLockSH(CfgGetBasedPath(szDomainsFilePath, szResLock));
+    RLCK_HANDLE     hResLock = RLckLockSH(CfgGetBasedPath(szDomainsFilePath, szResLock,
+                            sizeof(szResLock)));
 
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
@@ -569,7 +607,7 @@ char const     *MDomGetFirstDomain(DOMLS_HANDLE hDomainsDB)
 
         if (iFieldsCount >= domMax)
         {
-            strcpy(pDSD->szCurrDomain, ppszStrings[0]);
+            StrSNCpy(pDSD->szCurrDomain, ppszStrings[0]);
 
             pszDomain = pDSD->szCurrDomain;
         }
@@ -604,7 +642,7 @@ char const     *MDomGetNextDomain(DOMLS_HANDLE hDomainsDB)
 
         if (iFieldsCount >= domMax)
         {
-            strcpy(pDSD->szCurrDomain, ppszStrings[0]);
+            StrSNCpy(pDSD->szCurrDomain, ppszStrings[0]);
 
             pszDomain = pDSD->szCurrDomain;
         }
@@ -615,3 +653,44 @@ char const     *MDomGetNextDomain(DOMLS_HANDLE hDomainsDB)
     return (pszDomain);
 
 }
+
+
+
+int             MDomGetClientDomain(char const * pszFQDN, char * pszClientDomain,
+                        int iMaxDomain)
+{
+
+    for (; pszFQDN != NULL;)
+    {
+        if (MDomIsHandledDomain(pszFQDN) == 0)
+        {
+            StrNCpy(pszClientDomain, pszFQDN, iMaxDomain);
+
+            return (0);
+        }
+
+        if ((pszFQDN = strchr(pszFQDN, '.')) != NULL)
+            ++pszFQDN;
+    }
+
+    ErrSetErrorCode(ERR_NO_HANDLED_DOMAIN);
+    return (ERR_NO_HANDLED_DOMAIN);
+
+}
+
+
+
+int             MDomIsHandledDomain(char const * pszDomain)
+{
+///////////////////////////////////////////////////////////////////////////////
+//  Check for alias domain
+///////////////////////////////////////////////////////////////////////////////
+    char            szADomain[MAX_HOST_NAME] = "";
+
+    if (ADomLookupDomain(pszDomain, szADomain, true))
+        pszDomain = szADomain;
+
+
+    return (MDomLookupDomain(pszDomain));
+
+}
