@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,9 +43,9 @@ typedef struct DOMLS_HANDLE_struct
 
 
 int             MDomCheckDomainsIndexes(void);
-char           *MDomGetDomainPath(char const * pszDomain, char *pszDomainPath,
-                        int iFinalSlash = 1);
-int             MDomIsHandledDomain(char const * pszDomain);
+char           *MDomGetDomainPath(char const * pszDomain, char *pszDomainPath, int iMaxPath,
+                        int iFinalSlash);
+int             MDomLookupDomain(char const * pszDomain);
 int             MDomAddDomain(char const * pszDomain);
 int             MDomRemoveDomain(char const * pszDomain);
 int             MDomGetDomainsFileSnapShot(const char *pszFileName);
@@ -53,7 +53,9 @@ DOMLS_HANDLE    MDomOpenDB(void);
 void            MDomCloseDB(DOMLS_HANDLE hDomainsDB);
 char const     *MDomGetFirstDomain(DOMLS_HANDLE hDomainsDB);
 char const     *MDomGetNextDomain(DOMLS_HANDLE hDomainsDB);
-
+int             MDomGetClientDomain(char const * pszFQDN, char * pszClientDomain,
+                        int iMaxDomain);
+int             MDomIsHandledDomain(char const * pszDomain);
 
 
 
