@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include "MailConfig.h"
 #include "UsrUtils.h"
 #include "SvrUtils.h"
+#include "MessQueue.h"
 #include "MailSvr.h"
 #include "MiscUtils.h"
 
@@ -351,7 +352,8 @@ int             MscGetTimeStr(char *pszTimeStr, int iStringSize, time_t tCurr)
 
 
 
-int             MscGetDirectorySize(char const * pszPath, bool bRecurse, unsigned long &ulDirSize)
+int             MscGetDirectorySize(char const * pszPath, bool bRecurse, unsigned long &ulDirSize,
+                        unsigned long &ulNumFiles, int (*pFNValidate) (char const *))
 {
 
     char            szFileName[SYS_MAX_PATH] = "";
@@ -368,25 +370,32 @@ int             MscGetDirectorySize(char const * pszPath, bool bRecurse, unsigne
         {
             if (bRecurse && SYS_IS_VALID_FILENAME(szFileName))
             {
-                unsigned long   ulSubDirSize = 0;
+                unsigned long   ulSubDirSize = 0,
+                                ulSubNumFiles = 0;
                 char            szSubPath[SYS_MAX_PATH] = "";
 
-                strcpy(szSubPath, pszPath);
+                StrSNCpy(szSubPath, pszPath);
                 AppendSlash(szSubPath);
-                strcat(szSubPath, szFileName);
+                StrSNCat(szSubPath, szFileName);
 
-                if (MscGetDirectorySize(szSubPath, bRecurse, ulSubDirSize) < 0)
+                if (MscGetDirectorySize(szSubPath, bRecurse, ulSubDirSize,
+                        ulSubNumFiles, pFNValidate) < 0)
                 {
                     ErrorPush();
                     SysFindClose(hFind);
                     return (ErrorPop());
                 }
 
+                ulNumFiles += ulSubNumFiles;
                 ulDirSize += ulSubDirSize;
             }
         }
-        else
+        else if ((pFNValidate == NULL) || pFNValidate(szFileName))
+        {
+            ++ulNumFiles;
+
             ulDirSize += SysGetSize(hFind);
+        }
 
     } while (SysNextFile(hFind, szFileName));
 
@@ -554,9 +563,9 @@ int             MscClearDirectory(const char *pszPath, int iRecurseSubs)
             {
                 char            szSubPath[SYS_MAX_PATH] = "";
 
-                strcpy(szSubPath, pszPath);
+                StrSNCpy(szSubPath, pszPath);
                 AppendSlash(szSubPath);
-                strcat(szSubPath, szFileName);
+                StrSNCat(szSubPath, szFileName);
 
                 if (MscClearDirectory(szSubPath, iRecurseSubs) < 0)
                 {
@@ -592,9 +601,9 @@ int             MscClearDirectory(const char *pszPath, int iRecurseSubs)
         {
             char            szFilePath[SYS_MAX_PATH] = "";
 
-            strcpy(szFilePath, pszPath);
+            StrSNCpy(szFilePath, pszPath);
             AppendSlash(szFilePath);
-            strcat(szFilePath, szFileName);
+            StrSNCat(szFilePath, szFileName);
 
             if (SysRemove(szFilePath) < 0)
             {
@@ -682,7 +691,7 @@ int             MscCopyFile(FILE * pFileOut, FILE * pFileIn, unsigned long ulBas
     if (ulCopySize == (unsigned long) -1)
         ulCopySize = ulFileSize - ulBaseOffset;
     else
-        ulCopySize = min(ulCopySize, ulFileSize - ulBaseOffset);
+        ulCopySize = Min(ulCopySize, ulFileSize - ulBaseOffset);
 
     fseek(pFileIn, ulBaseOffset, SEEK_SET);
 
@@ -693,7 +702,7 @@ int             MscCopyFile(FILE * pFileOut, FILE * pFileIn, unsigned long ulBas
 
     while (ulCopySize > 0)
     {
-        unsigned int    uToRead = (unsigned int) min(ulCopySize, sizeof(szBuffer)),
+        unsigned int    uToRead = (unsigned int) Min(ulCopySize, sizeof(szBuffer)),
                         uReaded = fread(szBuffer, 1, uToRead, pFileIn);
 
         if (uReaded > 0)
@@ -875,14 +884,16 @@ char           *MscLogFilePath(char const * pszLogFile, char *pszLogFilePath)
 
     time(&tCurrent);
 
-    unsigned long   ulRotStep = (unsigned long) (3600L * iLogRotateHours);
-    time_t          tLogFileTime = (time_t) NbrFloor((unsigned long) tCurrent, ulRotStep);
+    unsigned long   ulRotStep = (unsigned long) (3600L * iLogRotateHours),
+                    ulTimeZone = SysGetTimeZone();
+    time_t          tLogFileTime = (time_t) (NbrFloor((unsigned long) tCurrent - ulTimeZone,
+                            ulRotStep) + ulTimeZone);
     struct tm       tmLogFileTime;
     char            szLogsDir[SYS_MAX_PATH] = "";
 
     SysLocalTime(&tLogFileTime, &tmLogFileTime);
 
-    SvrGetLogsDir(szLogsDir);
+    SvrGetLogsDir(szLogsDir, sizeof(szLogsDir));
     AppendSlash(szLogsDir);
 
     sprintf(pszLogFilePath, "%s%s-%04d%02d%02d%02d%02d",
@@ -1219,7 +1230,6 @@ int             MscLoadAddressFilter(char const * const * ppszFilter, int iNumTo
 
 
 
-
 bool            MscAddressMatch(AddressFilter const & AF, NET_ADDRESS TestAddr)
 {
 
@@ -1386,7 +1396,7 @@ int             MscBase64FileEncode(char const * pszBoundary, char const * pszFi
 //  Note that sizeof(szFileBuffer) must be multiple of 3
 ///////////////////////////////////////////////////////////////////////////////
     unsigned int    uReadSize;
-    char            szFileBuffer[240] = "",
+    char            szFileBuffer[80 * 3] = "",
                     szEncBuffer[512] = "";
 
     do
@@ -1397,7 +1407,7 @@ int             MscBase64FileEncode(char const * pszBoundary, char const * pszFi
         {
             unsigned int    uOutLength = sizeof(szEncBuffer);
 
-            encode64(szFileBuffer, uReadSize, szEncBuffer, sizeof(szEncBuffer), &uOutLength);
+            encode64(szFileBuffer, uReadSize, szEncBuffer, sizeof(szEncBuffer) - 1, &uOutLength);
 
             unsigned int    uWriteSize = 80;
             char           *pszWrite = szEncBuffer;
@@ -1520,27 +1530,25 @@ int             MscSetupServerNetPath(ServerNetPath & SvrPath, char const * pszC
 {
 
     char const     *pszColon = strchr(pszConnSpec, ':');
+    char            szServer[MAX_HOST_NAME] = "";
 
     ZeroData(SvrPath);
 
     if (pszColon != NULL)
     {
-        int             iIPLen = (int) (pszColon - pszConnSpec);
-        char            szIP[256] = "";
+        int             iIPLen = Min((int) (pszColon - pszConnSpec), sizeof(szServer) - 1);
 
-        strncpy(szIP, pszConnSpec, iIPLen = Min(iIPLen, sizeof(szIP) - 1));
-        szIP[iIPLen] = '\0';
+        strncpy(szServer, pszConnSpec, iIPLen);
+        szServer[iIPLen] = '\0';
+
+        pszConnSpec = szServer;
 
-        SvrPath.NetAddr = SysInetAddr(szIP);
         SvrPath.iPortNo = atoi(pszColon + 1);
     }
     else
-    {
-        SvrPath.NetAddr = SysInetAddr(pszConnSpec);
         SvrPath.iPortNo = iDefPortNo;
-    }
 
-    return (0);
+    return (MscGetServerAddress(pszConnSpec, SvrPath.NetAddr));
 
 }
 
@@ -1589,7 +1597,7 @@ SYS_UINT16      MscReadUint16(void const * pData)
 
 #else           // #if defined(CPU_NEED_ALIGNMENT)
 
-                    return (*(SYS_UINT16 const *) pData);
+    return (*(SYS_UINT16 const *) pData);
 
 #endif          // #if defined(CPU_NEED_ALIGNMENT)
 
@@ -1611,7 +1619,7 @@ SYS_UINT32      MscReadUint32(void const * pData)
 
 #else           // #if defined(CPU_NEED_ALIGNMENT)
 
-                    return (*(SYS_UINT32 const *) pData);
+    return (*(SYS_UINT32 const *) pData);
 
 #endif          // #if defined(CPU_NEED_ALIGNMENT)
 
@@ -1633,7 +1641,7 @@ SYS_UINT64      MscReadUint64(void const * pData)
 
 #else           // #if defined(CPU_NEED_ALIGNMENT)
 
-                    return (*(SYS_UINT64 const *) pData);
+    return (*(SYS_UINT64 const *) pData);
 
 #endif          // #if defined(CPU_NEED_ALIGNMENT)
 
@@ -1716,3 +1724,27 @@ int             MscCmdStringCheck(char const * pszString)
     return (0);
 
 }
+
+
+
+
+int             MscGetSectionSize(FileSection const * pFS, unsigned long * pulSize)
+{
+
+    if (pFS->ulEndOffset == (unsigned long) -1)
+    {
+        SYS_FILE_INFO       FI;
+
+        if (SysGetFileInfo(pFS->szFilePath, FI) < 0)
+            return (ErrGetErrorCode());
+
+
+        *pulSize = FI.ulSize - pFS->ulStartOffset;
+    }
+    else
+        *pulSize = pFS->ulEndOffset - pFS->ulStartOffset;
+
+
+    return (0);
+
+}
