@@ -1,6 +1,6 @@
 /*
- *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999  Davide Libenzi
+ *  XMail by Davide Libenzi ( Intranet and Internet mail server )
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Davide Libenzi <davide_libenzi@mycio.com>
+ *  Davide Libenzi <davidel@xmailserver.org>
  *
  */
 
@@ -36,6 +36,8 @@
 #include "UsrAuth.h"
 #include "POP3Svr.h"
 #include "POP3Utils.h"
+#include "MessQueue.h"
+#include "MailDomains.h"
 #include "MailConfig.h"
 #include "AppDefines.h"
 #include "MailSvr.h"
@@ -46,7 +48,7 @@
 
 #define POP3SRV_ACCEPT_TIMEOUT  4
 #define STD_POP3_TIMEOUT        30
-#define POP3_LISTEN_SIZE        8
+#define POP3_LISTEN_SIZE        64
 #define POP3_WAIT_SLEEP         2
 #define MAX_CLIENTS_WAIT        300
 #define POP3_IPMAP_FILE         "pop3.ipmap.tab"
@@ -97,6 +99,7 @@ static int      POP3ThreadCountAdd(long lCount, SHB_HANDLE hShbPOP3,
 static int      POP3LogEnabled(SHB_HANDLE hShbPOP3, POP3Config * pPOP3Cfg = NULL);
 static int      POP3CheckPeerIP(SYS_SOCKET SockFD);
 static unsigned int POP3ClientThread(void *pThreadData);
+static int      POP3CheckSysResources(SVRCFG_HANDLE hSvrConfig);
 static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock,
                         POP3Session & POP3S);
 static int      POP3LogSession(POP3Session & POP3S);
@@ -131,8 +134,7 @@ static int      POP3HandleCmd_LAST(const char *pszCommand, BSOCK_HANDLE hBSock,
                         POP3Session & POP3S);
 static int      POP3HandleCmd_RSET(const char *pszCommand, BSOCK_HANDLE hBSock,
                         POP3Session & POP3S);
-static int      POP3HandleCmd_RSET(const char *pszCommand, BSOCK_HANDLE hBSock,
-                        POP3Session & POP3S);
+
 
 
 
@@ -223,8 +225,8 @@ static int      POP3CheckPeerIP(SYS_SOCKET SockFD)
 
     char            szIPMapFile[SYS_MAX_PATH] = "";
 
-    CfgGetRootPath(szIPMapFile);
-    strcat(szIPMapFile, POP3_IPMAP_FILE);
+    CfgGetRootPath(szIPMapFile, sizeof(szIPMapFile));
+    StrNCat(szIPMapFile, POP3_IPMAP_FILE, sizeof(szIPMapFile));
 
     if (SysExistFile(szIPMapFile))
     {
@@ -248,19 +250,6 @@ static unsigned int POP3ClientThread(void *pThreadData)
 
     SYS_SOCKET      SockFD = (SYS_SOCKET) (unsigned int) pThreadData;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Create handle to hook shared memory
-///////////////////////////////////////////////////////////////////////////////
-    SHB_HANDLE      hShbPOP3 = ShbConnectBlock(SHB_POP3Svr);
-
-    if (hShbPOP3 == SHB_INVALID_HANDLE)
-    {
-        ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        SysCloseSocket(SockFD);
-        return (ErrorPop());
-    }
-
 ///////////////////////////////////////////////////////////////////////////////
 //  Link socket to the bufferer
 ///////////////////////////////////////////////////////////////////////////////
@@ -271,7 +260,6 @@ static unsigned int POP3ClientThread(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         SysCloseSocket(SockFD);
-        ShbCloseBlock(hShbPOP3);
         return (ErrorPop());
     }
 
@@ -285,7 +273,6 @@ static unsigned int POP3ClientThread(void *pThreadData)
         UPopSendErrorResponse(hBSock, ErrGetErrorCode(), STD_POP3_TIMEOUT);
 
         BSckDetach(hBSock, 1);
-        ShbCloseBlock(hShbPOP3);
         return (ErrorPop());
     }
 
@@ -299,7 +286,6 @@ static unsigned int POP3ClientThread(void *pThreadData)
         UPopSendErrorResponse(hBSock, ErrGetErrorCode(), STD_POP3_TIMEOUT);
 
         BSckDetach(hBSock, 1);
-        ShbCloseBlock(hShbPOP3);
         return (ErrorPop());
     }
 
@@ -321,8 +307,6 @@ static unsigned int POP3ClientThread(void *pThreadData)
     BSckDetach(hBSock, 1);
 
 
-    ShbCloseBlock(hShbPOP3);
-
     return (0);
 
 }
@@ -332,22 +316,12 @@ static unsigned int POP3ClientThread(void *pThreadData)
 unsigned int    POP3ThreadProc(void *pThreadData)
 {
 
-    SHB_HANDLE      hShbPOP3 = ShbConnectBlock(SHB_POP3Svr);
-
-    if (hShbPOP3 == SHB_INVALID_HANDLE)
-    {
-        ErrorPush();
-        SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        return (ErrorPop());
-    }
-
     POP3Config     *pPOP3Cfg = (POP3Config *) ShbLock(hShbPOP3);
 
     if (pPOP3Cfg == NULL)
     {
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-        ShbCloseBlock(hShbPOP3);
         return (ErrorPop());
     }
 
@@ -361,14 +335,11 @@ unsigned int    POP3ThreadProc(void *pThreadData)
         ErrorPush();
         SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
         ShbUnlock(hShbPOP3);
-        ShbCloseBlock(hShbPOP3);
         return (ErrorPop());
     }
 
     ShbUnlock(hShbPOP3);
 
-    SysIgnoreThreadsExit();
-
 
     SysLogMessage(LOG_LEV_MESSAGE, "%s started\n", POP3_SERVER_NAME);
 
@@ -403,7 +374,7 @@ unsigned int    POP3ThreadProc(void *pThreadData)
             if (hClientThread != SYS_INVALID_THREAD)
                 SysCloseThread(hClientThread, 0);
             else
-                SysCloseSocket(ConnSockFD[ss], 1);
+                SysCloseSocket(ConnSockFD[ss]);
 
         }
     }
@@ -431,8 +402,6 @@ unsigned int    POP3ThreadProc(void *pThreadData)
         SysSleep(POP3_WAIT_SLEEP);
     }
 
-    ShbCloseBlock(hShbPOP3);
-
     SysLogMessage(LOG_LEV_MESSAGE, "%s stopped\n", POP3_SERVER_NAME);
 
     return (0);
@@ -441,6 +410,23 @@ unsigned int    POP3ThreadProc(void *pThreadData)
 
 
 
+static int      POP3CheckSysResources(SVRCFG_HANDLE hSvrConfig)
+{
+///////////////////////////////////////////////////////////////////////////////
+//  Check virtual memory
+///////////////////////////////////////////////////////////////////////////////
+    int             iMinValue = SvrGetConfigInt("Pop3MinVirtMemSpace", -1, hSvrConfig);
+
+    if ((iMinValue > 0) && (SvrCheckVirtMemSpace(1024 * (unsigned long) iMinValue) < 0))
+        return (ErrGetErrorCode());
+
+
+    return (0);
+
+}
+
+
+
 static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock, POP3Session & POP3S)
 {
 
@@ -454,7 +440,8 @@ static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock, POP3Se
     if ((POP3S.hSvrConfig = SvrGetConfigHandle()) == INVALID_SVRCFG_HANDLE)
         return (ErrGetErrorCode());
 
-    if (SysGetPeerInfo(BSckGetAttachedSocket(hBSock), POP3S.PeerInfo) < 0)
+    if ((POP3CheckSysResources(POP3S.hSvrConfig) < 0) ||
+            (SysGetPeerInfo(BSckGetAttachedSocket(hBSock), POP3S.PeerInfo) < 0))
     {
         SvrReleaseConfigHandle(POP3S.hSvrConfig);
         return (ErrGetErrorCode());
@@ -463,10 +450,19 @@ static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock, POP3Se
 ///////////////////////////////////////////////////////////////////////////////
 //  Get connection socket host name
 ///////////////////////////////////////////////////////////////////////////////
+    char            szIP[128] = "???.???.???.???";
+
     if (MscGetSockHost(BSckGetAttachedSocket(hBSock), POP3S.szSvrFQDN) < 0)
-        strcpy(POP3S.szSvrFQDN, SysInetNToA(POP3S.PeerInfo));
+        StrSNCpy(POP3S.szSvrFQDN, SysInetNToA(POP3S.PeerInfo, szIP));
     else
-        MscSplitFQDN(POP3S.szSvrFQDN, NULL, POP3S.szSvrDomain);
+    {
+///////////////////////////////////////////////////////////////////////////////
+//  Try to get a valid domain from the FQDN
+///////////////////////////////////////////////////////////////////////////////
+        if (MDomGetClientDomain(POP3S.szSvrFQDN, POP3S.szSvrDomain,
+                        sizeof(POP3S.szSvrDomain) - 1) < 0)
+            StrSNCpy(POP3S.szSvrDomain, POP3S.szSvrFQDN);
+    }
 
 ///////////////////////////////////////////////////////////////////////////////
 //  If "POP3Domain" is defined, it's taken as default POP3 domain that means
@@ -477,7 +473,7 @@ static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock, POP3Se
 
     if (pszDefDomain != NULL)
     {
-        strcpy(POP3S.szSvrDomain, pszDefDomain);
+        StrSNCpy(POP3S.szSvrDomain, pszDefDomain);
 
         SysFree(pszDefDomain);
     }
@@ -485,7 +481,7 @@ static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock, POP3Se
 ///////////////////////////////////////////////////////////////////////////////
 //  As a last tentative We try to get "RootDomain" to set POP3 domain
 ///////////////////////////////////////////////////////////////////////////////
-    if (strlen(POP3S.szSvrDomain) == 0)
+    if (IsEmptyString(POP3S.szSvrDomain))
     {
         char           *pszRootDomain = SvrGetConfigVar(POP3S.hSvrConfig, "RootDomain");
 
@@ -496,7 +492,7 @@ static int      POP3InitSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock, POP3Se
             return (ERR_NO_DOMAIN);
         }
 
-        strcpy(POP3S.szSvrDomain, pszRootDomain);
+        StrSNCpy(POP3S.szSvrDomain, pszRootDomain);
 
         SysFree(pszRootDomain);
     }
@@ -530,19 +526,21 @@ static int      POP3LogSession(POP3Session & POP3S)
     MscGetTimeNbrString(szTime, sizeof(szTime) - 1);
 
 
-    RLCK_HANDLE     hResLock = RLckLockEX(SVR_LOGS_DIR "/" POP3_LOG_FILE);
+    RLCK_HANDLE     hResLock = RLckLockEX(SVR_LOGS_DIR SYS_SLASH_STR POP3_LOG_FILE);
 
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
 
 
+    char            szIP[128] = "???.???.???.???";
+
     MscFileLog(POP3_LOG_FILE, "\"%s\""
             "\t\"%s\""
             "\t\"%s\""
             "\t\"%s\""
             "\t\"%s\""
             "\t\"%s\""
-            "\n", POP3S.szSvrFQDN, POP3S.szSvrDomain, SysInetNToA(POP3S.PeerInfo),
+            "\n", POP3S.szSvrFQDN, POP3S.szSvrDomain, SysInetNToA(POP3S.PeerInfo, szIP),
             szTime, POP3S.szUser, POP3S.szPassword);
 
 
@@ -571,13 +569,16 @@ static int      POP3HandleSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock)
         return (ErrorPop());
     }
 
+
+    char            szIP[128] = "???.???.???.???";
+
     SysLogMessage(LOG_LEV_MESSAGE, "POP3 client connection from [%s]\n",
-            SysInetNToA(POP3S.PeerInfo));
+            SysInetNToA(POP3S.PeerInfo, szIP));
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Send welcome message
 ///////////////////////////////////////////////////////////////////////////////
-	char            szTime[256] = "";
+    char            szTime[256] = "";
 
     MscGetTimeStr(szTime, sizeof(szTime) - 1);
 
@@ -592,10 +593,12 @@ static int      POP3HandleSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock)
 ///////////////////////////////////////////////////////////////////////////////
 //  Command loop
 ///////////////////////////////////////////////////////////////////////////////
-    char            szCommand[2048] = "";
+    char            szCommand[1024] = "";
 
     while (!SvrInShutdown() && (POP3S.iPOP3State != stateExit) &&
-            (BSckGetString(hBSock, szCommand, sizeof(szCommand) - 1, POP3S.pPOP3Cfg->iSessionTimeout) != NULL))
+            (BSckGetString(hBSock, szCommand, sizeof(szCommand) - 1,
+                            POP3S.pPOP3Cfg->iSessionTimeout) != NULL) &&
+            (MscCmdStringCheck(szCommand) == 0))
     {
 ///////////////////////////////////////////////////////////////////////////////
 //  Retrieve a fresh new copy of configuration and test shutdown flag
@@ -615,7 +618,7 @@ static int      POP3HandleSession(SHB_HANDLE hShbPOP3, BSOCK_HANDLE hBSock)
     }
 
     SysLogMessage(LOG_LEV_MESSAGE, "POP3 client exit [%s]\n",
-            SysInetNToA(POP3S.PeerInfo));
+            SysInetNToA(POP3S.PeerInfo, szIP));
 
     POP3ClearSession(POP3S);
 
@@ -651,31 +654,31 @@ static int      POP3HandleCommand(const char *pszCommand, BSOCK_HANDLE hBSock,
 
     int             iCmdResult = -1;
 
-    if (StrINComp(pszCommand, "USER") == 0)
+    if (StrCmdMatch(pszCommand, "USER"))
         iCmdResult = POP3HandleCmd_USER(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "PASS") == 0)
+    else if (StrCmdMatch(pszCommand, "PASS"))
         iCmdResult = POP3HandleCmd_PASS(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "APOP") == 0)
+    else if (StrCmdMatch(pszCommand, "APOP"))
         iCmdResult = POP3HandleCmd_APOP(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "STAT") == 0)
+    else if (StrCmdMatch(pszCommand, "STAT"))
         iCmdResult = POP3HandleCmd_STAT(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "LIST") == 0)
+    else if (StrCmdMatch(pszCommand, "LIST"))
         iCmdResult = POP3HandleCmd_LIST(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "UIDL") == 0)
+    else if (StrCmdMatch(pszCommand, "UIDL"))
         iCmdResult = POP3HandleCmd_UIDL(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "QUIT") == 0)
+    else if (StrCmdMatch(pszCommand, "QUIT"))
         iCmdResult = POP3HandleCmd_QUIT(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "RETR") == 0)
+    else if (StrCmdMatch(pszCommand, "RETR"))
         iCmdResult = POP3HandleCmd_RETR(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "TOP") == 0)
+    else if (StrCmdMatch(pszCommand, "TOP"))
         iCmdResult = POP3HandleCmd_TOP(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "DELE") == 0)
+    else if (StrCmdMatch(pszCommand, "DELE"))
         iCmdResult = POP3HandleCmd_DELE(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "NOOP") == 0)
+    else if (StrCmdMatch(pszCommand, "NOOP"))
         iCmdResult = POP3HandleCmd_NOOP(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "LAST") == 0)
+    else if (StrCmdMatch(pszCommand, "LAST"))
         iCmdResult = POP3HandleCmd_LAST(pszCommand, hBSock, POP3S);
-    else if (StrINComp(pszCommand, "RSET") == 0)
+    else if (StrCmdMatch(pszCommand, "RSET"))
         iCmdResult = POP3HandleCmd_RSET(pszCommand, hBSock, POP3S);
     else
         BSckSendString(hBSock, "-ERR Invalid command", POP3S.pPOP3Cfg->iTimeout);
@@ -846,10 +849,16 @@ static int      POP3HandleCmd_PASS(const char *pszCommand, BSOCK_HANDLE hBSock,
         return (ErrorPop());
     }
 
+///////////////////////////////////////////////////////////////////////////////
+//  Save the user connection IP to use for SMTP authentication
+///////////////////////////////////////////////////////////////////////////////
+    UPopSaveUserIP(POP3S.hPOPSession);
+
+
     POP3S.iPOP3State = stateLogged;
 
 
-    int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+    int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession);
     unsigned long   ulMBSize = UPopGetSessionMBSize(POP3S.hPOPSession);
 
     BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout,
@@ -965,10 +974,16 @@ static int      POP3HandleCmd_APOP(const char *pszCommand, BSOCK_HANDLE hBSock,
         return (ErrorPop());
     }
 
+///////////////////////////////////////////////////////////////////////////////
+//  Save the user connection IP to use for SMTP authentication
+///////////////////////////////////////////////////////////////////////////////
+    UPopSaveUserIP(POP3S.hPOPSession);
+
+
     POP3S.iPOP3State = stateLogged;
 
 
-    int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+    int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession);
     unsigned long   ulMBSize = UPopGetSessionMBSize(POP3S.hPOPSession);
 
     BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout,
@@ -991,7 +1006,7 @@ static int      POP3HandleCmd_STAT(const char *pszCommand, BSOCK_HANDLE hBSock,
     }
 
 
-    int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+    int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession);
     unsigned long   ulMBSize = UPopGetSessionMBSize(POP3S.hPOPSession);
 
     BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout, "+OK %d %lu", iMsgCount, ulMBSize);
@@ -1012,20 +1027,19 @@ static int      POP3HandleCmd_LIST(const char *pszCommand, BSOCK_HANDLE hBSock,
         return (-1);
     }
 
-    int             iMsgIndex = -1;
-    char            szCmd[32] = "";
+    int             iMsgIndex = -1,
+                    iNumArgs = sscanf(pszCommand, "%*s %d", &iMsgIndex);
 
-    int             iNumArgs = sscanf(pszCommand, "%s %d", szCmd, &iMsgIndex);
-
-    if (iNumArgs == 1)
+    if (iNumArgs < 1)
     {
-        int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+        int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession),
+                        iMsgTotal = UPopGetSessionMsgTotal(POP3S.hPOPSession);
         unsigned long   ulMBSize = UPopGetSessionMBSize(POP3S.hPOPSession);
 
         BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout,
                 "+OK %d %lu", iMsgCount, ulMBSize);
 
-        for (int ii = 0; ii < iMsgCount; ii++)
+        for (int ii = 0; ii < iMsgTotal; ii++)
         {
             unsigned long   ulMessageSize = 0;
 
@@ -1072,18 +1086,17 @@ static int      POP3HandleCmd_UIDL(const char *pszCommand, BSOCK_HANDLE hBSock,
         return (-1);
     }
 
-    int             iMsgIndex = -1;
-    char            szCmd[32] = "";
+    int             iMsgIndex = -1,
+                    iNumArgs = sscanf(pszCommand, "%*s %d", &iMsgIndex);
 
-    int             iNumArgs = sscanf(pszCommand, "%s %d", szCmd, &iMsgIndex);
-
-    if (iNumArgs == 1)
+    if (iNumArgs < 1)
     {
-        int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+        int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession),
+                        iMsgTotal = UPopGetSessionMsgTotal(POP3S.hPOPSession);
 
         BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout, "+OK %d", iMsgCount);
 
-        for (int ii = 0; ii < iMsgCount; ii++)
+        for (int ii = 0; ii < iMsgTotal; ii++)
         {
             char            szMessageUIDL[256] = "";
 
@@ -1147,9 +1160,8 @@ static int      POP3HandleCmd_RETR(const char *pszCommand, BSOCK_HANDLE hBSock,
     }
 
     int             iMsgIndex = -1;
-    char            szCmd[32] = "";
 
-    if (sscanf(pszCommand, "%s %d", szCmd, &iMsgIndex) != 2)
+    if (sscanf(pszCommand, "%*s %d", &iMsgIndex) < 1)
     {
         BSckSendString(hBSock, "-ERR Invalid syntax", POP3S.pPOP3Cfg->iTimeout);
         return (-1);
@@ -1173,9 +1185,8 @@ static int      POP3HandleCmd_TOP(const char *pszCommand, BSOCK_HANDLE hBSock,
 
     int             iMsgIndex = -1,
                     iNumLines = 0;
-    char            szCmd[32] = "";
 
-    if (sscanf(pszCommand, "%s %d %d", szCmd, &iMsgIndex, &iNumLines) != 3)
+    if (sscanf(pszCommand, "%*s %d %d", &iMsgIndex, &iNumLines) < 2)
     {
         BSckSendString(hBSock, "-ERR Invalid syntax", POP3S.pPOP3Cfg->iTimeout);
         return (-1);
@@ -1198,9 +1209,8 @@ static int      POP3HandleCmd_DELE(const char *pszCommand, BSOCK_HANDLE hBSock,
     }
 
     int             iMsgIndex = -1;
-    char            szCmd[32] = "";
 
-    if (sscanf(pszCommand, "%s %d", szCmd, &iMsgIndex) != 2)
+    if (sscanf(pszCommand, "%*s %d", &iMsgIndex) < 1)
     {
         BSckSendString(hBSock, "-ERR Invalid syntax", POP3S.pPOP3Cfg->iTimeout);
         return (-1);
@@ -1232,7 +1242,7 @@ static int      POP3HandleCmd_NOOP(const char *pszCommand, BSOCK_HANDLE hBSock,
     }
 
 
-    int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+    int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession);
     unsigned long   ulMBSize = UPopGetSessionMBSize(POP3S.hPOPSession);
 
     BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout,
@@ -1277,7 +1287,7 @@ static int      POP3HandleCmd_RSET(const char *pszCommand, BSOCK_HANDLE hBSock,
     UPopResetSession(POP3S.hPOPSession);
 
 
-    int             iMsgCount = UPopGetSessionMsgCount(POP3S.hPOPSession);
+    int             iMsgCount = UPopGetSessionMsgCurrent(POP3S.hPOPSession);
     unsigned long   ulMBSize = UPopGetSessionMBSize(POP3S.hPOPSession);
 
     BSckVSendString(hBSock, POP3S.pPOP3Cfg->iTimeout,
