@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -46,7 +46,8 @@ typedef struct POP3_HANDLE_struct
 
 
 
-int             UPopGetMailboxSize(UserInfo * pUI, unsigned long &ulMBSize);
+int             UPopGetMailboxSize(UserInfo * pUI, unsigned long &ulMBSize,
+                        unsigned long &ulNumMessages);
 int             UPopCheckMailboxSize(UserInfo * pUI, unsigned long *pulAvailSpace = NULL);
 int             UPopAuthenticateAPOP(const char *pszDomain, const char *pszUsrName,
                         const char *pszTimeStamp, const char *pszDigest);
@@ -55,7 +56,8 @@ POP3_HANDLE     UPopBuildSession(const char *pszDomain, const char *pszUsrName,
 void            UPopReleaseSession(POP3_HANDLE hPOPSession, int iUpdate = 1);
 char           *UPopGetUserInfoVar(POP3_HANDLE hPOPSession, const char *pszName,
                         const char *pszDefault = NULL);
-int             UPopGetSessionMsgCount(POP3_HANDLE hPOPSession);
+int             UPopGetSessionMsgCurrent(POP3_HANDLE hPOPSession);
+int             UPopGetSessionMsgTotal(POP3_HANDLE hPOPSession);
 unsigned long   UPopGetSessionMBSize(POP3_HANDLE hPOPSession);
 int             UPopGetSessionLastAccessed(POP3_HANDLE hPOPSession);
 int             UPopGetMessageSize(POP3_HANDLE hPOPSession, int iMsgIndex,
@@ -69,10 +71,15 @@ int             UPopSessionSendMsg(POP3_HANDLE hPOPSession, int iMsgIndex,
                         BSOCK_HANDLE hBSock);
 int             UPopSessionTopMsg(POP3_HANDLE hPOPSession, int iMsgIndex, int iNumLines,
                         BSOCK_HANDLE hBSock);
+int             UPopSaveUserIP(POP3_HANDLE hPOPSession);
 int             UPopSyncRemoteLink(const char *pszSyncAddr, const char *pszRmtServer,
                         const char *pszRmtName, const char *pszRmtPassword,
+                        const char *pszFetchHdrTags = "+X-Deliver-To,To,Cc",
                         const char *pszAuthType = AUTH_TYPE_CLEAR,
                         const char * pszErrorAccount = NULL);
+int             UPopUserIpCheck(UserInfo * pUI, SYS_INET_ADDR const * pPeerInfo,
+                        unsigned int uExpireTime);
+int             UPopGetLastLoginAddress(UserInfo * pUI, SYS_INET_ADDR * pAddress);
 
 
 
