@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,10 +28,12 @@
 #include "SList.h"
 #include "BuffSock.h"
 #include "MiscUtils.h"
+#include "MailConfig.h"
 #include "SvrUtils.h"
 #include "UsrUtils.h"
 #include "POP3Svr.h"
 #include "POP3Utils.h"
+#include "MessQueue.h"
 #include "AppDefines.h"
 #include "MailSvr.h"
 #include "POP3GwLink.h"
@@ -41,9 +43,11 @@
 
 
 
+
+#define PSYNC_TRIGGER_FILE          ".psync-trigger"
 #define PSYNC_WAIT_SLEEP            2
 #define MAX_CLIENTS_WAIT            300
-#define PSYNC_WAKEUP_TIME           4
+#define PSYNC_WAKEUP_TIME           2
 #define PSYNC_SERVER_NAME           "[" APP_NAME_VERSION_OS_STR " PSYNC Server]"
 
 
@@ -52,6 +56,8 @@
 
 
 
+
+static bool     PSYNCNeedSync(void);
 static PSYNCConfig *PSYNCGetConfigCopy(SHB_HANDLE hShbPSYNC);
 static int      PSYNCThreadCountAdd(long lCount, SHB_HANDLE hShbPSYNC,
                         PSYNCConfig * pPSYNCCfg = NULL);
@@ -66,6 +72,31 @@ static int      PSYNCThreadNotifyExit(void);
 
 
 
+
+static bool     PSYNCNeedSync(void)
+{
+
+    char            szTriggerPath[SYS_MAX_PATH] = "";
+
+    CfgGetRootPath(szTriggerPath, sizeof(szTriggerPath));
+
+    StrNCat(szTriggerPath, PSYNC_TRIGGER_FILE, sizeof(szTriggerPath));
+
+///////////////////////////////////////////////////////////////////////////////
+//  Check for the presence of the trigger file
+///////////////////////////////////////////////////////////////////////////////
+    if (!SysExistFile(szTriggerPath))
+        return (false);
+
+
+    SysRemove(szTriggerPath);
+
+    return (true);
+
+}
+
+
+
 static PSYNCConfig *PSYNCGetConfigCopy(SHB_HANDLE hShbPSYNC)
 {
 
@@ -159,7 +190,8 @@ unsigned int    PSYNCThreadProc(void *pThreadData)
             break;
         }
 
-        if ((pPSYNCCfg->iSyncInterval == 0) || (iElapsedTime < pPSYNCCfg->iSyncInterval))
+        if (((pPSYNCCfg->iSyncInterval == 0) || (iElapsedTime < pPSYNCCfg->iSyncInterval)) &&
+                !PSYNCNeedSync())
         {
             SysFree(pPSYNCCfg);
             continue;
@@ -302,6 +334,14 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 
     char const     *pszErrorAccount = (IsEmptyString(szErrorAccount)) ? NULL: szErrorAccount;
 
+///////////////////////////////////////////////////////////////////////////////
+//  Get headers tags that must be checked to extract recipients
+///////////////////////////////////////////////////////////////////////////////
+    char            szFetchHdrTags[256] = "";
+
+    SvrConfigVar("FetchHdrTags", szFetchHdrTags, sizeof(szFetchHdrTags) - 1,
+            hSvrConfig, "+X-Deliver-To,+Received,To,Cc");
+
 ///////////////////////////////////////////////////////////////////////////////
 //  Lock the link
 ///////////////////////////////////////////////////////////////////////////////
@@ -347,7 +387,8 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
             UsrGetAddress(pUI, szUserAddress);
 
             if (UPopSyncRemoteLink(szUserAddress, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
-                            pPopLnk->pszRmtPassword, pPopLnk->pszAuthType, pszErrorAccount) < 0)
+                            pPopLnk->pszRmtPassword, szFetchHdrTags, pPopLnk->pszAuthType,
+                            pszErrorAccount) < 0)
                 ErrLogMessage(LOG_LEV_MESSAGE, "[PSYNC] User = \"%s\" - Domain = \"%s\" Failed !\n",
                         pPopLnk->pszName, pPopLnk->pszDomain);
 
@@ -369,7 +410,8 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 //  Sync ( "pszDomain" == "?" + masq-domain or "pszDomain" == "&" + add-domain )
 ///////////////////////////////////////////////////////////////////////////////
         if (UPopSyncRemoteLink(pPopLnk->pszDomain, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
-                        pPopLnk->pszRmtPassword, pPopLnk->pszAuthType, pszErrorAccount) < 0)
+                        pPopLnk->pszRmtPassword, szFetchHdrTags, pPopLnk->pszAuthType,
+                        pszErrorAccount) < 0)
             ErrLogMessage(LOG_LEV_MESSAGE,
                     "[PSYNC/MASQ] MasqDomain = \"%s\" - RmtDomain = \"%s\" - RmtName = \"%s\" Failed !\n",
                     pPopLnk->pszDomain + 1, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName);
@@ -390,7 +432,8 @@ unsigned int    PSYNCThreadSyncProc(void *pThreadData)
 //  Sync ( "pszDomain" == "@" + domain )
 ///////////////////////////////////////////////////////////////////////////////
         if (UPopSyncRemoteLink(szSyncAddress, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
-                        pPopLnk->pszRmtPassword, pPopLnk->pszAuthType, pszErrorAccount) < 0)
+                        pPopLnk->pszRmtPassword, szFetchHdrTags, pPopLnk->pszAuthType,
+                        pszErrorAccount) < 0)
             ErrLogMessage(LOG_LEV_MESSAGE,
                     "[PSYNC/EXT] Acount = \"%s\" - RmtDomain = \"%s\" - RmtName = \"%s\" Failed !\n",
                     szSyncAddress, pPopLnk->pszRmtDomain, pPopLnk->pszRmtName);
