@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -46,10 +46,8 @@ typedef struct RLCK_HANDLE_struct
 int             RLckInitLockers(void);
 int             RLckCleanupLockers(void);
 RLCK_HANDLE     RLckLockEX(char const * pszResourceName);
-RLCK_HANDLE     RLckLockEX(unsigned int uUserID, unsigned int uResID);
 int             RLckUnlockEX(RLCK_HANDLE hLock);
 RLCK_HANDLE     RLckLockSH(char const * pszResourceName);
-RLCK_HANDLE     RLckLockSH(unsigned int uUserID, unsigned int uResID);
 int             RLckUnlockSH(RLCK_HANDLE hLock);
 
 
