@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,11 +35,6 @@ struct SMAILConfig
 {
     unsigned long   ulFlags;
     long            lThreadCount;
-    int             iTimeout;
-    int             iRetryTimeout;
-    int             iRetryIncrRatio;
-    int             iMaxRetry;
-    int             iSleepTimeout;
 
 };
 
