@@ -81,10 +81,13 @@ int             USmtpIsAllowedRelay(const SYS_INET_ADDR & PeerInfo,
                         SVRCFG_HANDLE hSvrConfig);
 char          **USmtpGetPathStrings(const char *pszMailCmd);
 int             USmtpSplitEmailAddr(const char *pszAddr, char *pszUser, char *pszDomain);
+int             USmtpCheckAddressPart(char const *pszName);
+int             USmtpCheckAddress(char const *pszAddress);
 int             USmtpInitError(SMTPError * pSMTPE);
 bool            USmtpIsFatalError(SMTPError const * pSMTPE);
 char const     *USmtpGetErrorMessage(SMTPError const * pSMTPE);
 int             USmtpCleanupError(SMTPError * pSMTPE);
+char           *USmtpGetSMTPError(SMTPError * pSMTPE, char * pszError, int iMaxError);
 SMTPCH_HANDLE   USmtpCreateChannel(const char *pszServer, const char *pszDomain,
                         SMTPError * pSMTPE = NULL);
 int             USmtpCloseChannel(SMTPCH_HANDLE hSmtpCh, int iHardClose = 0, SMTPError * pSMTPE = NULL);
