@@ -148,7 +148,7 @@ char           *SysGetEnv(const char *pszVarName)
 }
 
 #else           // #if defined(WIN32)
-#if defined(__LINUX__) || defined(__SOLARIS__) || defined(__FREEBSD__)
+#if defined(__LINUX__) || defined(__SOLARIS__) || defined(__BSD__)
 
 #include <sys/stat.h>
 #include <stdio.h>
