@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #define _SYSDEP_H
 
 
+#define SYS_SHUTDOWN_SOFT           0
 
 #define LOG_LEV_DEBUG               0
 #define LOG_LEV_MESSAGE             1
@@ -45,7 +46,9 @@
 
 int             SysInitLibrary(void);
 void            SysCleanupLibrary(void);
+int             SysShutdownLibrary(int iMode = SYS_SHUTDOWN_SOFT);
 
+int             SysSetupSocketBuffers(int *piSndBufSize, int *piRcvBufSize);
 SYS_SOCKET      SysCreateSocket(int iAddressFamily, int iType, int iProtocol);
 void            SysCloseSocket(SYS_SOCKET SockFD);
 int             SysBindSocket(SYS_SOCKET SockFD, const struct sockaddr * SockName, int iNameLen);
@@ -64,15 +67,15 @@ SYS_SOCKET      SysAccept(SYS_SOCKET SockFD, SYS_INET_ADDR * pSockName, int *iNa
                         int iTimeout);
 int             SysSelect(int iMaxFD, SYS_fd_set * pReadFDs, SYS_fd_set * pWriteFDs, SYS_fd_set * pExcptFDs,
                         int iTimeout);
-int             SysSendFile(SYS_SOCKET SockFD, char const * pszFileName, int iTimeout,
-                        int (*pSendCB) (void *) = NULL, void *pUserData = NULL);
+int             SysSendFile(SYS_SOCKET SockFD, char const * pszFileName, unsigned long ulBaseOffset,
+                        unsigned long ulEndOffset, int iTimeout);
 int             SysSetupAddress(SYS_INET_ADDR & AddrInfo, int iFamily, NET_ADDRESS NetAddr, int iPortNo);
 NET_ADDRESS     SysGetAddrAddress(SYS_INET_ADDR const & AddrInfo);
 NET_ADDRESS     SysGetHostByName(char const * pszName);
 int             SysGetHostByAddr(SYS_INET_ADDR const & AddrInfo, char *pszFQDN);
 int             SysGetPeerInfo(SYS_SOCKET SockFD, SYS_INET_ADDR & AddrInfo);
 int             SysGetSockInfo(SYS_SOCKET SockFD, SYS_INET_ADDR & AddrInfo);
-char const     *SysInetNToA(SYS_INET_ADDR const & AddrInfo);
+char           *SysInetNToA(SYS_INET_ADDR const & AddrInfo, char * pszIP);
 NET_ADDRESS     SysInetAddr(char const * pszDotName);
 
 SYS_SEMAPHORE   SysCreateSemaphore(int iInitCount, int iMaxCount);
@@ -129,12 +132,14 @@ void            SysSleep(int iTimeout);
 void            SysMsSleep(int iMsTimeout);
 SYS_INT64       SysMsTime(void);
 int             SysExistFile(const char *pszFilePath);
+int             SysExistDir(const char *pszDirPath);
 SYS_HANDLE      SysFirstFile(const char *pszPath, char *pszFileName);
 int             SysIsDirectory(SYS_HANDLE hFind);
 unsigned long   SysGetSize(SYS_HANDLE hFind);
 int             SysNextFile(SYS_HANDLE hFind, char *pszFileName);
 void            SysFindClose(SYS_HANDLE hFind);
 int             SysGetFileInfo(char const * pszFileName, SYS_FILE_INFO & FI);
+int             SysSetFileModTime(char const * pszFileName, time_t tMod);
 char           *SysStrDup(const char *pszString);
 char           *SysGetEnv(const char *pszVarName);
 char           *SysGetTmpFile(char *pszFileName);
@@ -144,16 +149,22 @@ int             SysRemoveDir(const char *pszPath);
 int             SysMoveFile(char const * pszOldName, char const * pszNewName);
 
 int             SysVSNPrintf(char *pszBuffer, int iSize, char const * pszFormat, va_list Args);
+int             SysFileSync(FILE *pFile);
 
 char           *SysStrTok(char *pszData, char const * pszDelim, char **ppszSavePtr);
 char           *SysCTime(time_t * pTimer, char *pszBuffer, int iBufferSize);
 struct tm      *SysLocalTime(time_t * pTimer, struct tm * pTStruct);
 struct tm      *SysGMTime(time_t * pTimer, struct tm * pTStruct);
 char           *SysAscTime(struct tm * pTStruct, char *pszBuffer, int iBufferSize);
+unsigned long   SysGetTimeZone(void);
 
 int             SysSpinAcquire(SYS_SPINLOCK * pSpinLock);
 int             SysSpinRelease(SYS_SPINLOCK * pSpinLock);
 
+int             SysGetDiskSpace(char const * pszPath, SYS_INT64 * pTotal, SYS_INT64 * pFree);
+int             SysMemoryInfo(SYS_INT64 * pRamTotal, SYS_INT64 * pRamFree,
+                        SYS_INT64 * pVirtTotal, SYS_INT64 * pVirtFree);
+
 
 
 
