@@ -49,15 +49,15 @@
 #include "SysIncludeSolaris.h"
 
 #else           // #ifdef __SOLARIS__
-#ifdef __FREEBSD__
+#ifdef __BSD__
 
-#include "SysIncludeFreeBSD.h"
+#include "SysIncludeBSD.h"
 
-#else           // #ifdef __FREEBSD__
+#else           // #ifdef __BSD__
 
 #error System type not defined
 
-#endif          // #ifdef __FREEBSD__
+#endif          // #ifdef __BSD__
 #endif          // #ifdef __SOLARIS__
 #endif          // #ifdef __LINUX__
 #endif          // #ifdef WIN32
