@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,2000,2001  Davide Libenzi
+ *  Copyright (C) 1999,...,2002  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,8 +50,6 @@
 #define SysSNPrintf             snprintf
 #define stricmp                 strcasecmp
 #define strnicmp                strncasecmp
-#define min(a, b)               (((a) < (b)) ? (a): (b))
-#define max(a, b)               (((a) > (b)) ? (a): (b))
 
 #define SYS_fd_set              fd_set
 #define SYS_FD_ZERO             FD_ZERO
@@ -59,6 +57,7 @@
 #define SYS_FD_SET              FD_SET
 #define SYS_FD_ISSET            FD_ISSET
 
+#define SYS_SPINLOCK_UNLOCKED   0
 
 
 
@@ -107,7 +106,6 @@ struct SYS_FILE_INFO
 {
     int             iFileType;
     unsigned long   ulSize;
-    time_t          tCreat;
     time_t          tMod;
 };
 
