@@ -1831,7 +1831,7 @@ int             UsrModifyUser(UserInfo * pUI)
 ///////////////////////////////////////////////////////////////////////////////
 //  Try ( if defined ) to modify external auth user
 ///////////////////////////////////////////////////////////////////////////////
-    UAthModifyUser(AUTH_SERVICE_POP3, pFoundUI);
+    UAthModifyUser(AUTH_SERVICE_POP3, pUI);
 
 
     UsrFreeUserInfo(pFoundUI);
@@ -2693,7 +2693,7 @@ int             UsrMoveToMailBox(UserInfo * pUI, char const * pszFileName,
 
 
 
-int             UsrGetMailProcessFile(UserInfo * pUI, char *pszMPPath)
+int             UsrGetMailProcessFile(UserInfo * pUI, char const * pszMPPath)
 {
 
     char            szMPFilePath[SYS_MAX_PATH] = "";
@@ -2717,8 +2717,6 @@ int             UsrGetMailProcessFile(UserInfo * pUI, char *pszMPPath)
     if (hResLock == INVALID_RLCK_HANDLE)
         return (ErrGetErrorCode());
 
-    SysGetTmpFile(pszMPPath);
-
     if (MscCopyFile(pszMPPath, szMPFilePath) < 0)
     {
         ErrorPush();
